# Utils

Various functions and classes.

## Common

All-purpose functions.

```{eval-rst}
.. automodule:: gismap.utils.common
    :members:
```

## Requests

Functions related to the `requests`.

```{eval-rst}
.. automodule:: gismap.utils.requests
    :members:
```

## Logger

Keep track of things.

```{eval-rst}
.. automodule:: gismap.utils.logger
    :members:
```

## Zlist

Convert a list into a succession of compressed frames. Reduces memory footprint at the price of slower random access (sequential access is unaffected).

```{eval-rst}
.. automodule:: gismap.utils.zlist
    :members:
```


## Text

Text manipulation tools.

```{eval-rst}
.. automodule:: gismap.utils.text
    :members:
```
